@@ -12,6 +12,13 @@ class LeapImage:
     type: LeapDataType = LeapDataType.Image
 
 
+@dataclass
+class LeapImageWithBBox:
+    data: np.array
+    bbox: np.array
+    type: LeapDataType = LeapDataType.ImageWithBBox
+
+
 @dataclass
 class LeapNumeric:
     data: np.array
@@ -51,5 +58,3 @@ class LeapTextMask:
     text_array: np.array
     labels: List[str]
     type: LeapDataType = LeapDataType.TextMask
-
-
